pub enum DeriveReplaceOutcome {
Replaced(DeriveOrder),
Canceled {
cancelled_order: DeriveOrder,
create_order_error: JsonRpcError,
},
}Expand description
Confirmed outcome returned by private/replace.
Variants
Replaced(DeriveOrder)
The stale order was cancelled and the replacement was accepted.
Canceled
The stale order was cancelled but replacement creation failed.
Fields

cancelled_order: DeriveOrderCancelled stale order returned by the venue.

create_order_error: JsonRpcErrorStructured error returned by replacement creation.